.. _glossary:

Glossary
========

.. glossary::
   :sorted:

   Jinja2
      A `templating system written by Armin Ronacher
      <http://jinja.pocoo.org/>`_.

   Pyramid
      A `web framework <http://pylonshq.com/pyramid>`_.
